
AC_DEFUN(AC_PATH_QT,
[
  AC_ARG_WITH(qt,
    [  --with-qt               where QT v3.x.x or higher is located. ],
    [  QTDIR="$withval" ])
])


AC_DEFUN(AC_PATH_QT_LIB,
[
  AC_REQUIRE_CPP()
  AC_REQUIRE([AC_PATH_X])
  AC_MSG_CHECKING(for QT libraries)

  AC_ARG_WITH(qt-libraries,
    [  --with-qt-libraries     where the QT libraries are located. ],
    [  ac_qt_libraries="$withval" ], ac_qt_libraries="")

  AC_CACHE_VAL(ac_cv_lib_qtlib, [

      qt_libname=
      qt_libdir=

      dnl No they didnt, so lets look for them...
      dnl If you need to add extra directories to check, add them here.
      if test -z "$ac_qt_libraries"; then
        qt_library_dirs="\
          /usr/lib/qt3/lib \
          /usr/lib/qt2/lib \
	  /usr/lib/qt-3.1/lib \
          /usr/lib \
          /usr/local/lib \
          /usr/lib/qt \
          /usr/lib/qt/lib \
          /usr/local/lib/qt \
          /usr/local/qt/lib \
          /usr/X11/lib \
          /usr/X11/lib/qt \
          /usr/X11R6/qt3/lib \
          /usr/X11R6/lib \
          /usr/X11R6/lib/qt"
      else
        qt_library_dirs="$ac_qt_libraries"
      fi

      if test -n "$QTDIR"; then
        qt_library_dirs="$QTDIR/lib $qt_library_dirs"
      fi

      if test -n "$QTLIB"; then
        qt_library_dirs="$QTLIB $qt_library_dirs"
      fi

      for qt_dir in $qt_library_dirs; do
        if test -r "$qt_dir/libqt-mt.so"; then
          ac_qt_libname=-lqt-mt
          ac_qt_libdir=$qt_dir
          break
        else
          echo "tried $qt_dir/libqt-mt.so" >&AC_FD_CC 
        fi

        if test -r "$qt_dir/libqt.so"; then
          ac_qt_libname=-lqt
          ac_qt_libdir=$qt_dir
          break
        else
          echo "tried $qt_dir/libqt.so" >&AC_FD_CC 
        fi
      done

    ac_cv_lib_qtlib="ac_qt_libname=$ac_qt_libname ac_qt_libdir=$ac_qt_libdir"
  ])

  eval "$ac_cv_lib_qtlib"

  dnl Define a shell variable for later checks

  if test -z "$ac_qt_libdir"; then
    have_qt_lib="no"
    AC_MSG_RESULT([no :-(])
  else
    have_qt_lib="yes"
    AC_MSG_RESULT([yes, lib: $ac_qt_libname in $ac_qt_libdir])
  fi

  QT_LDFLAGS="-L$ac_qt_libdir"
  QT_LIBDIR="$ac_qt_libdir"
  LIB_QT="$ac_qt_libname"
  AC_SUBST(QT_LDFLAGS)
  AC_SUBST(QT_LIBDIR)
  AC_SUBST(LIB_QT)
])


AC_DEFUN(AC_PATH_QT_INC,
[
  AC_REQUIRE_CPP()
  AC_REQUIRE([AC_PATH_X])
  AC_MSG_CHECKING(for QT includes)

  AC_ARG_WITH(qt-includes,
    [  --with-qt-includes      where the QT headers are located. ],
    [  ac_qt_includes="$withval" ], ac_qt_includes="")

  AC_CACHE_VAL(ac_cv_header_qtinc, [

    dnl Did the user give --with-qt-includes?
    if test -z "$ac_qt_includes"; then

      dnl No they didn't, so lets look for them...
      dnl If you need to add extra directories to check, add them here.
      qt_include_dirs="\
        /usr/lib/qt3/include \
        /usr/lib/qt2/include \
	/usr/lib/qt-3.1/include \
        /usr/lib/qt/include \
        /usr/include/qt \
        /usr/include/qt3 \
        /usr/local/qt/include \
        /usr/local/include/qt \
        /usr/X11/include/qt \
        /usr/X11/include/X11/qt \
        /usr/X11R6/qt3/include \
        /usr/X11R6/include \
        /usr/X11R6/include/qt \
        /usr/X11R6/include/X11/qt \
        /usr/X11/lib/qt/include"

      if test -n "$QTDIR"; then
        qt_include_dirs="$QTDIR/include $qt_include_dirs"
      fi

      if test -n "$QTINC"; then
        qt_include_dirs="$QTINC $qt_include_dirs"
      fi

      for qt_dir in $qt_include_dirs; do
        if test -r "$qt_dir/qwidget.h"; then
          if ! test -r "$qt_dir/qprinter.h"; then
            AC_MSG_ERROR([
              This is not Qt 3.0.0 or later. Somebody cheated you.
            ])
          else
            ac_qt_includes=$qt_dir
          fi
          break
        fi
      done
    fi

    ac_cv_header_qtinc=$ac_qt_includes

  ])

  if test -z "$ac_cv_header_qtinc"; then
    have_qt_inc="no"
  else
    have_qt_inc="yes"
  fi

  AC_MSG_RESULT([$ac_cv_header_qtinc])
  QT_INCLUDES="-I$ac_cv_header_qtinc"
  QT_INCDIR="$ac_cv_header_qtinc"
  AC_SUBST(QT_INCLUDES)
  AC_SUBST(QT_INCDIR)
])


AC_DEFUN(AC_PATH_QT_MOC,
[
  AC_ARG_WITH(qt-moc,
    [  --with-qt-moc           where the QT 3.x.x moc is located. ],
    [  ac_qt_moc="$withval" ], ac_qt_moc="")

  if test -z "$ac_qt_moc"; then
    dnl search on our own

    if test -z "$QTDIR"; then
      AC_MSG_WARN(environment variable QTDIR is not set, moc might not be found)
    fi

    AC_PATH_PROG(
      MOC,
      moc,
      $QTDIR/bin/moc,
      $QTDIR/bin:/usr/lib/qt2/bin:/usr/bin:/usr/X11R6/bin:/usr/X11R6/qt3/bin:/usr/lib/qt/bin:/usr/local/qt/bin:$PATH
    )
  else
    AC_MSG_CHECKING(for moc)

    if test -f $ac_qt_moc && test -x $ac_qt_moc; then
      MOC=$ac_qt_moc
    else
      AC_MSG_ERROR(
        --with-qt-moc expects path and name of the moc
      )
    fi

    AC_MSG_RESULT($MOC)
  fi

  if test -z "$MOC"; then
    AC_MSG_ERROR(couldn't find Qt moc. Please use --with-qt-moc)
  fi

  dnl Check if we have the right moc
  if ! fgrep QCString "$MOC" > /dev/null; then
    AC_MSG_ERROR([

        The Qt meta object compiler (moc)
        $MOC
        found by configure is not the one part of Qt 3.x.x.

        It's likely that the found one is the one shipped with
        Qt 1.xx. That one will not work.

        Please check your installation.
        Use the --with-qt-moc option to specify the path and name
        of the moc compiler shipped with your Qt 3.x lib.
        Some distributions rename it to "moc2", maybe you find that
        on your system.

        see ./configure --help for details.
    ])
  fi

  AC_SUBST(MOC)
])

AC_DEFUN(AC_PATH_AVIFILE_INC,
[
  AC_REQUIRE_CPP()
  AC_MSG_CHECKING(for avifile includes)

  AC_ARG_WITH(avifile-includes,
    [  --with-avifile-includes      where the AVIFILE headers are located. ],
    [  ac_avifile_includes="$withval" ], ac_avifile_includes="")

  AC_CACHE_VAL(ac_cv_header_avifileinc, [

    dnl Did the user give --with-avifile-includes?
    if test -z "$ac_avifile_includes"; then

      dnl No they didn't, so lets look for them...
      dnl If you need to add extra directories to check, add them here.
      avifile_include_dirs="\
        /usr/local/include \
        /usr/pkg/include \
        /usr/pkg/include/avifile \
        /usr/local/include/avifile \
        /usr/include/avifile"

      for avifile_dir in $avifile_include_dirs; do
        if test -r "$avifile_dir/aviplay.h"; then
            ac_avifile_includes=$avifile_dir
        fi
      done
    fi

    ac_cv_header_avifileinc=$ac_avifile_includes

  ])

  if test -z "$ac_cv_header_avifileinc"; then
    have_avifile_inc="no"
  else
    have_avifile_inc="yes"
  fi

  AC_MSG_RESULT([$ac_cv_header_avifileinc])
  AVIFILE_INCLUDES="-I$ac_cv_header_avifileinc"
  AVIFILE_INCDIR="$ac_cv_header_avifileinc"
  AC_SUBST(AVIFILE_INCLUDES)
  AC_SUBST(AVIFILE_INCDIR)
])

AC_DEFUN(AC_PATH_AVIFILE_LIB,
[
  AC_REQUIRE_CPP()
  AC_MSG_CHECKING(for avifile library)

  AC_ARG_WITH(avifile-libraries,
    [  --with-avifile-libraries     where the AVIFILE libraries are located. ],
    [  ac_avifile_libraries="$withval" ], ac_avifile_libraries="")

  AC_CACHE_VAL(ac_cv_lib_avifilelib, [

      avifile_libname=
      avifile_libdir=

      dnl No they didnt, so lets look for them...
      dnl If you need to add extra directories to check, add them here.
      if test -z "$ac_avifile_libraries"; then
        avifile_library_dirs="\
          /usr/local/lib \
          /usr/pkg/lib \
          /usr/lib"
      else
        avifile_library_dirs="$ac_avifile_libraries"
      fi

      for avifile_dir in $avifile_library_dirs; do
        if test -r "$avifile_dir/libaviplay.so"; then
          ac_avifile_libname=-laviplay
          ac_avifile_libdir=$avifile_dir
          break
        else
          echo "tried $avifile_dir/libaviplay.so" >&AC_FD_CC 
        fi
      done

    ac_cv_lib_avifilelib="ac_avifile_libname=$ac_avifile_libname ac_avifile_libdir=$ac_avifile_libdir"
  ])

  eval "$ac_cv_lib_avifilelib"

  dnl Define a shell variable for later checks

  if test -z "$ac_avifile_libdir"; then
    have_avifile_lib="no"
    AC_MSG_RESULT([no :-(])
  else
    have_avifile_lib="yes"
    AC_MSG_RESULT([yes, lib: $ac_avifile_libname in $ac_avifile_libdir])
  fi

  AVIFILE_LDFLAGS="-L$ac_avifile_libdir"
  AVIFILE_LIBDIR="$ac_avifile_libdir"
  LIB_AVIFILE="$ac_avifile_libname"
  AC_SUBST(AVIFILE_LDFLAGS)
  AC_SUBST(AVIFILE_LIBDIR)
  AC_SUBST(LIB_AVIFILE)
])


# ogg.m4
# Configure paths for libogg
# Jack Moffitt <jack@icecast.org> 10-21-2000
# Shamelessly stolen from Owen Taylor and Manish Singh

dnl AM_PATH_OGG([ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Test for libogg, and define OGG_CFLAGS and OGG_LIBS
dnl
AC_DEFUN(AM_PATH_OGG,
[dnl 
dnl Get the cflags and libraries
dnl
AC_ARG_WITH(ogg-prefix,[  --with-ogg-prefix=PFX   Prefix where libogg is installed (optional)], ogg_prefix="$withval", ogg_prefix="")
AC_ARG_ENABLE(oggtest, [  --disable-oggtest       Do not try to compile and run a test Ogg program],, enable_oggtest=yes)

  if test x$ogg_prefix != x ; then
    ogg_args="$ogg_args --prefix=$ogg_prefix"
    OGG_CFLAGS="-I$ogg_prefix/include"
    OGG_LIBS="-L$ogg_prefix/lib"
  fi

  OGG_LIBS="$OGG_LIBS -logg"

  AC_MSG_CHECKING(for Ogg)
  no_ogg=""


  if test "x$enable_oggtest" = "xyes" ; then
    ac_save_CFLAGS="$CFLAGS"
    ac_save_LIBS="$LIBS"
    CFLAGS="$CFLAGS $OGG_CFLAGS"
    LIBS="$LIBS $OGG_LIBS"
dnl
dnl Now check if the installed Ogg is sufficiently new.
dnl
      rm -f conf.oggtest
      AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ogg/ogg.h>

int main ()
{
  system("touch conf.oggtest");
  return 0;
}

],, no_ogg=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
  fi

  if test "x$no_ogg" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$1], , :, [$1])     
  else
     AC_MSG_RESULT(no)
     if test -f conf.oggtest ; then
       :
     else
       echo "*** Could not run Ogg test program, checking why..."
       CFLAGS="$CFLAGS $OGG_CFLAGS"
       LIBS="$LIBS $OGG_LIBS"
       AC_TRY_LINK([
#include <stdio.h>
#include <ogg/ogg.h>
],     [ return 0; ],
       [ echo "*** The test program compiled, but did not run. This usually means"
       echo "*** that the run-time linker is not finding Ogg or finding the wrong"
       echo "*** version of Ogg. If it is not finding Ogg, you'll need to set your"
       echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
       echo "*** to the installed location  Also, make sure you have run ldconfig if that"
       echo "*** is required on your system"
       echo "***"
       echo "*** If you have an old version installed, it is best to remove it, although"
       echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"],
       [ echo "*** The test program failed to compile or link. See the file config.log for the"
       echo "*** exact error that occured. This usually means Ogg was incorrectly installed"
       echo "*** or that you have moved Ogg since it was installed. In the latter case, you"
       echo "*** may want to edit the ogg-config script: $OGG_CONFIG" ])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
     OGG_CFLAGS=""
     OGG_LIBS=""
     ifelse([$2], , :, [$2])
  fi
  AC_SUBST(OGG_CFLAGS)
  AC_SUBST(OGG_LIBS)
  rm -f conf.oggtest
])

# vorbis.m4
# Configure paths for libvorbis
# Jack Moffitt <jack@icecast.org> 10-21-2000
# Shamelessly stolen from Owen Taylor and Manish Singh

dnl AM_PATH_VORBIS([ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Test for libvorbis, and define VORBIS_CFLAGS and VORBIS_LIBS
dnl
AC_DEFUN(AM_PATH_VORBIS,
[dnl 
dnl Get the cflags and libraries
dnl
AC_ARG_WITH(vorbis-prefix,[  --with-vorbis-prefix=PFX   Prefix where libvorbis is installed (optional)], vorbis_prefix="$withval", vorbis_prefix="")
AC_ARG_ENABLE(vorbistest, [  --disable-vorbistest       Do not try to compile and run a test Vorbis program],, enable_vorbistest=yes)

  if test x$vorbis_prefix != x ; then
    vorbis_args="$vorbis_args --prefix=$vorbis_prefix"
    VORBIS_CFLAGS="-I$vorbis_prefix/include"
    VORBIS_LIBS="-L$vorbis_prefix/lib"
  fi

  VORBIS_LIBS="$VORBIS_LIBS -lvorbisfile -lvorbis -lm"

  AC_MSG_CHECKING(for Vorbis)
  no_vorbis=""


  if test "x$enable_vorbistest" = "xyes" ; then
    ac_save_CFLAGS="$CFLAGS"
    ac_save_LIBS="$LIBS"
    CFLAGS="$CFLAGS $VORBIS_CFLAGS"
    LIBS="$LIBS $VORBIS_LIBS $OGG_LIBS"
dnl
dnl Now check if the installed Vorbis is sufficiently new.
dnl
      rm -f conf.vorbistest
      AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <vorbis/codec.h>

int main ()
{
  system("touch conf.vorbistest");
  return 0;
}

],, no_vorbis=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
  fi

  if test "x$no_vorbis" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$1], , :, [$1])     
  else
     AC_MSG_RESULT(no)
     if test -f conf.vorbistest ; then
       :
     else
       echo "*** Could not run Vorbis test program, checking why..."
       CFLAGS="$CFLAGS $VORBIS_CFLAGS"
       LIBS="$LIBS $VORBIS_LIBS $OGG_LIBS"
       AC_TRY_LINK([
#include <stdio.h>
#include <vorbis/codec.h>
],     [ return 0; ],
       [ echo "*** The test program compiled, but did not run. This usually means"
       echo "*** that the run-time linker is not finding Vorbis or finding the wrong"
       echo "*** version of Vorbis. If it is not finding Vorbis, you'll need to set your"
       echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
       echo "*** to the installed location  Also, make sure you have run ldconfig if that"
       echo "*** is required on your system"
       echo "***"
       echo "*** If you have an old version installed, it is best to remove it, although"
       echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"],
       [ echo "*** The test program failed to compile or link. See the file config.log for the"
       echo "*** exact error that occured. This usually means Vorbis was incorrectly installed"
       echo "*** or that you have moved Vorbis since it was installed." ])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
     VORBIS_CFLAGS=""
     VORBIS_LIBS=""
     ifelse([$2], , :, [$2])
  fi
  AC_SUBST(VORBIS_CFLAGS)
  AC_SUBST(VORBIS_LIBS)
  rm -f conf.vorbistest
])
